@@ -8,6 +8,7 @@ from spotPython.hyperparameters.values import (
     assign_values,
     generate_one_config_from_var_dict,
 )
+from spotPython.utils.eda import generate_config_id
 
 
 logger = logging.getLogger(__name__)
@@ -64,10 +65,7 @@ class HyperTorch:
         # type information and transformations are considered in generate_one_config_from_var_dict:
         for config in generate_one_config_from_var_dict(var_dict, self.fun_control):
             print(f"\nconfig: {config}")
-            config_id = ""
-            for key in config:
-                config_id += str(config[key]) + "_"
-            config_id = config_id[:-1]
+            config_id = generate_config_id(config)
             if self.fun_control["prep_model"] is not None:
                 model = make_pipeline(self.fun_control["prep_model"], self.fun_control["core_model"](**config))
             else:
